@@ -94,8 +94,11 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 
 #[cfg(test)]
 mod tests {
+    use crate::test::reset;
+
     #[test]
     fn test_generate() {
+        reset();
         with_settings!({
             let out = assert_cli!("config", "generate");
             for line in out.lines() {
