@@ -3,6 +3,7 @@ use std::path::PathBuf;
 use clap::ValueHint;
 use color_eyre::eyre::{eyre, Result};
 use console::style;
+use eyre::bail;
 use path_absolutize::Absolutize;
 
 use crate::cli::args::ToolArg;
@@ -45,7 +46,7 @@ impl Link {
                 style(path.to_string_lossy()).cyan().for_stderr()
             );
         }
-        let target = self.tool.forge.installs_path.join(version);
+        let target = self.tool.backend.installs_path.join(version);
         if target.exists() {
             if self.force {
                 remove_all(&target)?;
@@ -80,9 +81,14 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 #[cfg(test)]
 mod tests {
     use crate::file::create_dir_all;
+    use crate::test::reset;
+    use test_log::test;
 
     #[test]
     fn test_link() {
+        reset();
+        assert_cli!("install", "tiny@1.0.1", "tiny@2.1.0");
+        assert_cli!("install", "tiny@3.0.1", "tiny@3.1.0");
         create_dir_all("../data/tmp/tiny").unwrap();
         assert_cli!("link", "tiny@9.8.7", "../data/tmp/tiny");
         assert_cli_snapshot!("ls", "tiny", @r###"
