@@ -45,7 +45,8 @@ use super::args::ToolArg;
 ///     outputs = ["dist/**/*.js"]
 ///
 /// Alternatively, tasks can be defined as standalone scripts.
-/// These must be located in the `.mise/tasks`, `mise/tasks` or `.config/mise/tasks` directory.
+/// These must be located in `mise-tasks`, `.mise-tasks`, `.mise/tasks`, `mise/tasks` or
+/// `.config/mise/tasks`.
 /// The name of the script will be the name of the tasks.
 ///
 ///     $ cat .mise/tasks/build<<EOF
@@ -296,9 +297,18 @@ impl Run {
             let filename = file.display().to_string();
             self.exec(&filename, args, task, env, prefix)
         } else {
-            let script = format!("{} {}", script, shell_words::join(args));
-            let args = vec!["-c".to_string(), script];
-            self.exec("sh", &args, task, env, prefix)
+            #[cfg(windows)]
+            {
+                let script = format!("{} {}", script, args.join(" "));
+                let args = vec!["/c".to_string(), script];
+                self.exec("cmd", &args, task, env, prefix)
+            }
+            #[cfg(unix)]
+            {
+                let script = format!("{} {}", script, shell_words::join(args));
+                let args = vec!["-c".to_string(), script];
+                self.exec("sh", &args, task, env, prefix)
+            }
         }
     }
 
